Name:		module-build-service
Version:	1.3.9
Release:	1%{?dist}
Summary:	The Module Build Service for Modularity

Group:		Development/Tools
License:	MIT
URL:		https://pagure.io/fm-orchestrator
Source0:	https://files.pythonhosted.org/packages/source/m/%{name}/%{name}-%{version}.tar.gz

%if 0%{?rhel} && 0%{?rhel} <= 7
# In EL7 we need flask which needs python-itsdangerous which comes from
# rhel7-extras which is only available on x86_64 for now.
ExclusiveArch: %{ix86} x86_64
%else
BuildArch:	noarch
%endif

BuildRequires:	python2-devel

BuildRequires:	python2-mock
BuildRequires:	python-vcrpy
BuildRequires:	fedmsg
BuildRequires:	git
BuildRequires:	help2man
BuildRequires:	kobo
BuildRequires:	kobo-rpmlib
BuildRequires:	koji
BuildRequires:	m2crypto
BuildRequires:	mock
BuildRequires:	pdc-client
BuildRequires:	pyOpenSSL
BuildRequires:	python-fedora
BuildRequires:	python-flask
BuildRequires:	python-flask-script
BuildRequires:	python-httplib2
BuildRequires:	python-m2ext
BuildRequires:	python-munch
BuildRequires:	python-six
BuildRequires:	python-sqlalchemy
BuildRequires:	python2-funcsigs
BuildRequires:	python2-modulemd >= 1.1.0
BuildRequires:	rpm-build
BuildRequires:	python-qpid
BuildRequires:	python-futures

%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:	python-setuptools
BuildRequires:	python-flask-sqlalchemy
BuildRequires:	python-flask-migrate
BuildRequires:	python-nose
BuildRequires:	python-mock
%else
BuildRequires:	python2-setuptools
BuildRequires:	python2-flask-sqlalchemy
BuildRequires:	python2-flask-migrate
BuildRequires:	python2-nose
BuildRequires:	python2-mock
%endif

BuildRequires:	systemd
%{?systemd_requires}

Requires:	systemd
Requires:	fedmsg
Requires:	fedmsg-hub
Requires:	git
Requires:	kobo
Requires:	kobo-rpmlib
Requires:	koji
Requires:	m2crypto
Requires:	mock
Requires:	pdc-client
Requires:	pyOpenSSL
Requires:	python-fedora
Requires:	python-flask
Requires:	python-flask-script
Requires:	python-httplib2
Requires:	python-m2ext
Requires:	python-munch
Requires:	python-six
Requires:	python-sqlalchemy
Requires:	python2-funcsigs
Requires:	python2-modulemd >= 1.1.0
Requires:	rpm-build
Requires:	python-qpid
Requires:	python-futures

%if 0%{?rhel} && 0%{?rhel} <= 7
Requires:	python-flask-sqlalchemy
Requires:	python-flask-migrate
Requires:	python-mock
%else
Requires:	python2-flask-sqlalchemy
Requires:	python2-flask-migrate
Requires:	python2-mock
%endif


%description
The Module Build Service (MBS) coordinates module builds and is responsible
for a number of tasks:

- Providing an interface for module client-side tooling via which module build
  submission and build state queries are possible.
- Verifying the input data (modulemd, RPM SPEC files and others) is available
  and correct.
- Preparing the build environment in the supported build systems, such as koji.
- Scheduling and building of the module components and tracking the build
  state.
- Emitting bus messages about all state changes so that other infrastructure
  services can pick up the work.


%prep
%setup -q

# Simply remove an old .pyc file that was included in one release.
rm -f module_build_service/scheduler/consumer.pyc
# And this weird sqlite file that made it in...
rm -f module_build_service/.mbs_local_build.db


%build
%py2_build


%install
%py2_install

export PYTHONPATH=%{buildroot}%{python2_sitelib}
mkdir -p %{buildroot}/%{_mandir}/man1
for command in mbs-manager mbs-frontend mbs-gencert mbs-upgradedb ; do
MBS_CONFIG_FILE=conf/config.py help2man -N --version-string=%{version} \
	%{buildroot}/%{_bindir}/$command > \
	%{buildroot}/%{_mandir}/man1/$command.1
done


# Still failing https://pagure.io/fm-orchestrator/issue/381
#%check
#nosetests-2.7 -v


%files
%doc README.rst
%license LICENSE
%{python2_sitelib}/module_build_service*
%{_bindir}/mbs-*
%{_mandir}/man1/mbs-*.1*
%dir %{_sysconfdir}/module-build-service
%config(noreplace) %{_sysconfdir}/module-build-service/config.py
%config(noreplace) %{_sysconfdir}/module-build-service/koji.conf
%config(noreplace) %{_sysconfdir}/module-build-service/copr.conf
%config(noreplace) %{_sysconfdir}/module-build-service/cacert.pem
%config(noreplace) %{_sysconfdir}/fedmsg.d/mbs-scheduler.py
%config(noreplace) %{_sysconfdir}/fedmsg.d/mbs-logging.py
%config(noreplace) %{_sysconfdir}/fedmsg.d/module_build_service.py
%exclude %{_sysconfdir}/module-build-service/*.py[co]
%exclude %{_sysconfdir}/fedmsg.d/*.py[co]
%exclude %{python2_sitelib}/conf/
%exclude %{python2_sitelib}/tests/


%changelog
* Thu Mar 16 2017 Ralph Bean <rbean@redhat.com> - 1.3.9-1
- new version

* Wed Mar 15 2017 Ralph Bean <rbean@redhat.com> - 1.3.8-1
- new version

* Tue Mar 14 2017 Ralph Bean <rbean@redhat.com> - 1.3.6-1
- new version

* Tue Mar 14 2017 Ralph Bean <rbean@redhat.com> - 1.3.5-1
- new version

* Mon Mar 13 2017 Ralph Bean <rbean@redhat.com> - 1.3.4-1
- new version

* Fri Mar 03 2017 Ralph Bean <rbean@redhat.com> - 1.3.3-1
- new version

* Fri Mar 03 2017 Petr Šabata <contyk@redhat.com> - 1.3.2-3
- MBS requires modulemd-1.1.0+ to work properly

* Thu Mar 02 2017 Ralph Bean <rbean@redhat.com> - 1.3.2-2
- Conditionalize arch for epel7 building.

* Thu Mar 02 2017 Ralph Bean <rbean@redhat.com> - 1.3.2-1
- new version

* Tue Feb 28 2017 Ralph Bean <rbean@redhat.com> - 1.3.1-2
- Disable the test suite in koji for now.

* Tue Feb 28 2017 Ralph Bean <rbean@redhat.com> - 1.3.1-1
- new version

* Wed Feb 15 2017 Ralph Bean <rbean@redhat.com> - 1.2.0-1
- new version

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb  1 2017 Filip Valder <fvalder@redhat.com> - 1.1.1-2
- New revision (deps & cleanups)

* Tue Jan 31 2017 Ralph Bean <rbean@redhat.com> - 1.1.1-1
- new version

* Tue Jan 24 2017 Ralph Bean <rbean@redhat.com> - 1.1.0-3
- Include fedmsg.d/mbs-scheduler.py by default.

* Wed Jan 18 2017 Ralph Bean <rbean@redhat.com> - 1.1.0-2
- Dep fixes (for EPEL7).

* Tue Jan 17 2017 Ralph Bean <rbean@redhat.com> - 1.1.0-1
- new version

* Wed Jan 11 2017 Ralph Bean <rbean@redhat.com> - 1.0.2-4
- Conditionalize some deps for EPEL7.

* Wed Jan 11 2017 Ralph Bean <rbean@redhat.com> - 1.0.2-3
- Sync spec file from upstream git.

* Thu Dec 15 2016 Matt Prahl <mprahl@redhat.com> - 1.0.2-2
- Replace systemd unit with fedmsg-hub
- Remove an old .pyc file that got included by accident.

* Wed Dec 14 2016 Ralph Bean <rbean@redhat.com> - 1.0.2-1
- Enable test suite in the check section.
- Add systemd scriptlets, per review feedback.

* Mon Dec 12 2016 Ralph Bean <rbean@redhat.com> - 1.0.1-1
- Cleanup in preparation for package review.

* Tue Dec 6 2016 Matt Prahl <mprahl@redhat.com> - 1.0.0-2
- Adds systemd unit.

* Fri Nov 25 2016 Filip Valder <fvalder@redhat.com> - 1.0.0-1
- Let's get this party started.
